..
   Generated: Thu Mar 23 15:03:55 2017

   @author : Eric Lapouyade

=====
parse
=====

.. automodule:: textops.ops.parse
.. currentmodule:: textops

find_first_pattern
------------------
   .. autoclass:: find_first_pattern(patterns)

find_first_patterni
-------------------
   .. autoclass:: find_first_patterni(patterns)

find_pattern
------------
   .. autoclass:: find_pattern(pattern)

find_patterni
-------------
   .. autoclass:: find_patterni(pattern)

find_patterns
-------------
   .. autoclass:: find_patterns(patterns)

find_patternsi
--------------
   .. autoclass:: find_patternsi(patterns)

keyval
------
   .. autoclass:: keyval(pattern, key_name='key', key_update=None, val_name=None)

keyvali
-------
   .. autoclass:: keyvali(pattern, key_name='key', key_update=None, val_name=None)

mgrep
-----
   .. autoclass:: mgrep(patterns_dict, key=None)

mgrepi
------
   .. autoclass:: mgrepi(patterns_dict, key=None)

mgrepv
------
   .. autoclass:: mgrepv(patterns_dict, key=None)

mgrepvi
-------
   .. autoclass:: mgrepvi(patterns_dict, key=None)

parse_indented
--------------
   .. autoclass:: parse_indented(sep=':')

parse_smart
-----------
   .. autoclass:: parse_smart()

parseg
------
   .. autoclass:: parseg(pattern)

parsegi
-------
   .. autoclass:: parsegi(pattern)

parsek
------
   .. autoclass:: parsek(pattern, key_name='key', key_update=None)

parseki
-------
   .. autoclass:: parseki(pattern, key_name='key', key_update=None)

parsekv
-------
   .. autoclass:: parsekv(pattern, key_name='key', key_update=None, val_name=None)

parsekvi
--------
   .. autoclass:: parsekvi(pattern, key_name='key', key_update=None, val_name=None)

sgrep
-----
   .. autoclass:: sgrep(patterns, key=None)

sgrepi
------
   .. autoclass:: sgrepi(patterns, key=None)

sgrepv
------
   .. autoclass:: sgrepv(patterns, key=None)

sgrepvi
-------
   .. autoclass:: sgrepvi(patterns, key=None)

state_pattern
-------------
   .. autoclass:: state_pattern(states_patterns_desc, reflags=0, autostrip=True)
